@@ -36,7 +36,6 @@
 
 #include "gvm.h"
 
-#define GVM_DEBUG
 #ifdef GVM_DEBUG
 # define dbg(fmt,arg...) fprintf(stderr, "%s/%d: " fmt,__FILE__,__LINE__,##arg)
 #else
@@ -1237,7 +1236,7 @@ gvm_device_mounted (const char *udi)
 static gboolean
 gvm_device_mount (const char *udi, int apply_policy)
 {
-	char *mount_point, *fstype, *options[2];
+	char *mount_point, *fstype, *options[2], **poptions;
 	struct _MountPolicy *policy;
 	DBusMessage *dmesg, *reply;
 	dbus_uint64_t size;
@@ -1261,9 +1260,10 @@ gvm_device_mount (const char *udi, int apply_policy)
 	if (size <= (256 * 1024 * 1024))
 		options[noptions++] = "sync";
 	options[noptions] = NULL;
+	poptions = options;
 	
 	if (!dbus_message_append_args (dmesg, DBUS_TYPE_STRING, &mount_point, DBUS_TYPE_STRING, &fstype,
-				       DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options, noptions,
+				       DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &poptions, noptions,
 				       DBUS_TYPE_INVALID)) {
 		dbg ("mount failed for %s: could not append args to dbus message\n", udi);
 		dbus_message_unref (dmesg);
@@ -2155,6 +2155,7 @@ mount_all (LibHalContext *ctx)
 		if (!(drive = libhal_device_get_property_string (ctx, udi, "info.parent", NULL)))
 			continue;
 		
+		mount = FALSE;
 		if (libhal_device_property_exists (ctx, drive, "storage.hotpluggable", NULL)
 		    && libhal_device_get_property_bool (ctx, drive, "storage.hotpluggable", NULL))
 			mount = config.automount_drives;
